Lifetime Exception Rest API — Rucio 1.2 documentation

# Lifetime Exception Rest API

Overview

Resource | Operation | Description
--- | --- | ---
LifetimeException | POST /lifetime_exceptions/ | Create new exception.
| GET /lifetime_exceptions/ | Get all exceptions.
LifetimeExceptionId | PUT /lifetime_exceptions/(exception_id) | Approve/reject exception.
| GET /lifetime_exceptions/(exception_id) | Get an exceptions.

Details

`POST` `/lifetime_exceptions/`

  Create a new Lifetime Model exception.

  Request JSON Object:
  | dids (string) – The list of dids. pattern (string) – The pattern. comments (string) – The comment for the exception. expires_at (string) – The expiration date for the exception.
  Response Headers:
  | Content-Type – application/json
  Status Codes: | 201 Created – Created. 400 Bad Request – Cannot decode json parameter list. 401 Unauthorized – Invalid Auth Token. 409 Conflict – Lifetime Exception already exists. 500 Internal Server Error – Internal Error.
  Returns: | The id for the newly created execption.

`GET` `/lifetime_exceptions/`

  Retrieve all exceptions.

  Response Headers:
  | Content-Type – application/x-json-stream
  Status Codes: | 200 OK – OK. 401 Unauthorized – Invalid Auth Token. 404 Not Found – Lifetime Exception Not Found. 500 Internal Server Error – Internal Error.

`PUT` `/lifetime_exceptions/`(exception_id)

  Approve/Reject an execption.

  Parameters: | exception_id – The exception identifier.
  Request JSON Object:
  | state (string) – the new state (APPROVED/REJECTED)
  Status Codes: | 201 Created – Created. 400 Bad Request – Cannot decode json parameter list. 401 Unauthorized – Invalid Auth Token. 404 Not Found – Lifetime Exception Not Found.
  Status 500: | Internal Error.

`GET` `/lifetime_exceptions/`(exception_id)

  Retrieve an exception.

  Parameters: | exception_id – The exception identifier.
  Response Headers:
  | Content-Type – application/x-json-stream
  Status Codes: | 200 OK – OK. 401 Unauthorized – Invalid Auth Token. 404 Not Found – Lifetime Exception Not Found. 500 Internal Server Error – Internal Error.
  Returns: | List of exceptions.